@@ -5,13 +5,13 @@
 #include <osmium/geom/projection.hpp>
 
 TEST_CASE("Indentity Projection") {
-    osmium::geom::IdentityProjection projection;
+    const osmium::geom::IdentityProjection projection;
     REQUIRE(4326 == projection.epsg());
     REQUIRE("+proj=longlat +datum=WGS84 +no_defs" == projection.proj_string());
 }
 
 TEST_CASE("Projection 4326") {
-    osmium::geom::Projection projection{4326};
+    const osmium::geom::Projection projection{4326};
     REQUIRE(4326 == projection.epsg());
     REQUIRE("+init=epsg:4326" == projection.proj_string());
 
@@ -22,7 +22,7 @@ TEST_CASE("Projection 4326") {
 }
 
 TEST_CASE("Projection 4326 from init string") {
-    osmium::geom::Projection projection{"+init=epsg:4326"};
+    const osmium::geom::Projection projection{"+init=epsg:4326"};
     REQUIRE(-1 == projection.epsg());
     REQUIRE("+init=epsg:4326" == projection.proj_string());
 
@@ -41,7 +41,7 @@ TEST_CASE("Creating projection from unknown EPSG code") {
 }
 
 TEST_CASE("Projection 3857") {
-    osmium::geom::Projection projection{3857};
+    const osmium::geom::Projection projection{3857};
     REQUIRE(3857 == projection.epsg());
     REQUIRE("+init=epsg:3857" == projection.proj_string());
 
@@ -75,7 +75,7 @@ TEST_CASE("Projection 3857") {
 }
 
 TEST_CASE("MercatorProjection: Zero coordinates") {
-    osmium::geom::MercatorProjection projection;
+    const osmium::geom::MercatorProjection projection;
     const osmium::Location loc{0.0, 0.0};
     const osmium::geom::Coordinates c{0.0, 0.0};
     REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.00001));
@@ -83,7 +83,7 @@ TEST_CASE("MercatorProjection: Zero coordinates") {
 }
 
 TEST_CASE("MercatorProjection: Max longitude") {
-    osmium::geom::MercatorProjection projection;
+    const osmium::geom::MercatorProjection projection;
     const osmium::Location loc{180.0, 0.0};
     const osmium::geom::Coordinates c{20037508.34, 0.0};
     REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.00001));
@@ -91,7 +91,7 @@ TEST_CASE("MercatorProjection: Max longitude") {
 }
 
 TEST_CASE("MercatorProjection: Min longitude") {
-    osmium::geom::MercatorProjection projection;
+    const osmium::geom::MercatorProjection projection;
     const osmium::Location loc{-180.0, 0.0};
     const osmium::geom::Coordinates c{-20037508.34, 0.0};
     REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.00001));
@@ -99,7 +99,7 @@ TEST_CASE("MercatorProjection: Min longitude") {
 }
 
 TEST_CASE("MercatorProjection: Max latitude") {
-    osmium::geom::MercatorProjection projection;
+    const osmium::geom::MercatorProjection projection;
     const osmium::Location loc{0.0, 85.0511288};
     const osmium::geom::Coordinates c{0.0, 20037508.34};
     REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.00001));
